;CAPTURE.ASM
;Here is an example of one of the timer functions.  The capture pins on
;the 68HC11 tell us when an event takes place.  The pins can be triggered
;by falling or rising pulse edges.  If we capture the time of a rising edge
;and then change the registers to capture the next falling edge we can 
;measure the time between a leading and trailing edge of a pulse and then
;compute the pulse width.  If we measure only rising edges or only falling
;edges then we could measure the time between two pulses. That is what we
;do in this example which was adapted from an example in Chapter 11 of the
;textbook by Peter Spasov listed in the references in the User's Manual.
;
;PROGRAM CAPTURES THE TIME BETWEEN THE FALLING EDGE OF TWO INCOMING PULSES
;
;Assemble: AS11 CAPTURE.ASM
;
;Run program at the Debugger Prompt: B 0100
;
;
;
;  The input capture registers TIC1, TIC2, and TIC3 are all
;  16-bit registers.  They make a capture when an edge occurs
;   on one of these input pins.  When a capture is made on one of
;   the registers, the time of the capture is copied from the TCNT
;   register into the input capture register.  TCNT register is
;   the free-running counter.   The ouput of the E clock is connected
;   to TCNT counter.    TCNT is cleared at RESET.   This is read only;
;   it cannot be written but it will incremented by every tick of the
;   E clock.  One tick of the E clock takes 1.085uS on the AES11 board.
;
;   one full count (FFFFH) in TCNT is 71msec.
;
;
;   To capture the time between the falling edge of two pulses:

;   Connect the input line to PA.1 (IC2 pin).  IC2 pin is designed
;   to use with TIC2 register.
;   
;   Set up the TCTL2 register for capturing on falling edge on IC2 pin.  
;   When the falling edge triggered, IC2F flag in TLFG1 register sets and 
;   the captured time is stored in TIC2 register.  So after setting up
;   the TCTL2 register, clear any pending IC2F flag.  After that,
;   have the program running in a loop; polling for an IC2F flag
;   to be set. When IC2F flag set, have the program read the captured 
;   time in TIC2 register and stores it in memory.  After that, clear 
;   the IC2F flag by writting a 1 to the corresponding bit in TLFG1 
;   register.   Make one more capture for the second falling edge, and 
;   store it to another location in memory.  TCNT is a 16-bit free-running 
;   counter. It will rolls from FFFFH to 0000H.  The time copied from
;   TCNT to any of the input capture register is varied.  If
;   the time capture on the second falling edge is smaller the
;   the time of the first pulse, add FFFFh to the second time
;   and make the subtraction. Assumed TCNT just rolled one.
;
;
;   The difference in time captured (count) times 1.085uS/count 
;   will give the time between two falling edge of two incoming pulses 
;   on the same input line.

;  

TCTL2   EQU     $21             ;TIMER CONTROL REGISTER 2
TFLG1   EQU     $23             ;MAIN TIMER INTERRUPT FLAG REGISTER 1

TIC2    EQU     $12             ;TIMER INPUT CAPTURE 2

        
        ORG     $100            ;program starts at 100H


        LDX     #$6000          ;base address of HC11 's I/O registers
                                ;on the AES11.
                                 
                                ;setup value for TCTL2 control register
                                ;which control the input capture registers
        LDAA    #$8             ;IC2 captures on falling edge
                                ;see M68HC11  Reference Manual, page 10-17

        STAA    TCTL2,X         ;TCTL2 register address is at 6021H

        LDAA    #$2             ;0000 0010, mask value to clear flags
                                ;in TLFG1
        STAA    TFLG1,X         ;clear IC2 flag if had.
                                ;TFLG1 is at 6023H
                                
                                      ;now, wait for the falling edge

LOOP1   BRCLR   TFLG1,X #$02 LOOP1    ;IC2F flag is not set, keep on looping
                                      ;IC2F set on falling edge, program
                                      ;continues below...
        
        LDD     TIC2,X                ;read first captured time in TIC2
        STD     DATA1                 ;save in memory
        
        LDAA    #$2                   ;clear the IC2F flag for next capture
        STAA    TFLG1,X               ;

LOOP2   BRCLR   TFLG1,X #$02 LOOP2    ;wait for the 2nd falling edge
                                     
        LDD     TIC2,X               ;read time captured on the 2nd falling
        STD     DATA2                ;edge and save DATA2


;DATA2 , DATA1 contain the time captured.
;use the "M 0300"  command at the DEBUGGER PROMPT to view the results.
;
;
;       .....
;       .....                       ;place more codes to
;       .....                       ;subtract DATA1 from DATA2
                                    ;print to the screen, etc.

        RTS                         ;program ends
        
        
        ORG     300H    ;at 300H

DATA1   FDB             ;reversed 2 bytes for storing time on 
                        ;falling edge of the 1st pulse.

DATA2   FDB             ;reversed 2 bytes for storing time 
                        ;on the  falling edge of the 2nd pulse.



