;THERMO2.ASM
;10/02/1996
;AES-11 ' Sample Program like Thermo.asm except now we use a National
;Semiconductor LM35 temperature sensor instead of a thermistor.
;
;Assemble and Run Program:
;AS11 THERMO2.ASM
;B 0100

;Program makes A/D conversion at PE.0 pin and coverts it to
;temperature in Centigrate.  Program then displays the temperature
;on the LCD display.
;
;Materials used:
; Temperature Sensor, LM35DH ( 1 degree C/10mVolt)
; (1) 10K Resistor
; (1) 1 uF Capacitor
; (1) AES-11 System
;
;Misc. Info:
;
; Analog Input from PE.0 = D * RESOLUTION
;       where D is the A/D number from the conversion at PE.0 pin
;       RESOLUTION = VRh-Vrl / (2^8) = Apx. 19.37mV on the AES11 Board.
;
;      
; Temperature in degrees C = Analog Input from PE.0 / 10mV
; Instead of dividing the voltage by 0.010 to get temperature we
; multiply the voltage by 100.  Therefore instead of using 19.37mV
; we use 1937mV (1.937 volts) as a factor.
;
; Temperature = D * 1.937    (final equation for temperature)
;
;
; Connections:    ________
;                |        |        Resister
;  Vs (5V+)______|        |Vout----[10K]--o--------------------> to PE.0
;                | LM35DH |               |
;                |________|               |
;                     |                 ----- +
;                     |                 ----- - 1uF Capacitor
;                    GND                  |
;                                         |
;                                        GND
;
; If you don't have a LM35 just put a variable resistor (pot) with the
; center tap at PE0 and change the voltage while running this program
; to see the results change on the LCD.
;
;program uses built-in floating-point routines, and other ROM routines.
;
;ROM routines used:
;           
;
; $902A, Sends text string indexed by IX; ended with zero byte to
;        the LCD Display.
;
; $9000, routine to clear the LCD Display.
; $9021, A/D conversion at PE.0 pin

;
; Addresses of ROM routines on the AES-11 board.

LCDCLS  EQU $9000       ;clear LCD display.
LCDTEXT EQU $902A       ;send ASCII string to the LCD Display.
ADPE0   EQU $9021       ;A/D conversion at PE.0 pin.


;Addresses of floating-point routines
;see user's manual page 7-5

ASCFLT  EQU $9050       ;ASCII TO FLOAT CONVERSION
FLTMUL  EQU $9053       ;FLOATING-POINT MULTIPLY
FLTSUB  EQU $9059       ;FLOATING-POINT SUBTRACT
FLTASC  EQU $905F       ;FLOATING-POINT TO ASCII CONVERSION
TFR1TO2 EQU $906E       ;TRANSFER FLOATING-POINT ACCUMULATOR #1 (FPACC1)
                        ;TO FLOATING-POINT ACCUMULATOR #2 (FPACC2)

UINT2FLT EQU $9065      ;UNSIGNED INTEGER TO FLOATING-POINT

                        ;see user 's manual for floating
                        ;point format of FPACC1

                        ;FPACC1 contains 5 bytes starting at $6100
EXPONENT EQU $6100      ;ADDRESS of FPACC1 's exponent
MAN1     EQU $6101      ;Address of first byte mantissa
MAN2     EQU $6102       ;Address of the second-byte mantissa
MAN3     EQU $6103       ;Address of the third-byte mantissa
SIGN     EQU $6104       ;Address of the byte which indicated the
                        ;mantissa sign



        ORG     $100            ;program starts at 100Hex
        JMP     MAIN            ;jump to program 's main code.

TBUFF   RMB     15               ;reserved 14 bytes for TBUFF.
                                 ;for storing answer of temperature.
                                 ;Answer is in ASCII STRING

CONST1  FCC '19.37E-1'           ;a constant in ASCII string.
        FCB 0H                   ;for use later in floating-point
                                 ;routines.


        ORG     $200

MAIN:
        JSR     ADPE0           ;read A/D conversion; result in $6040
        LDAA    $6040           ;read result

                                ;now we want to convert the hexadecimal
                                ;number into floating-point number.
                                ;we can use the floating-point routine,
                                ;UINT2FLT
                                ;see chapter 7 in the user's manual
                                ;since the mantissa is 3 bytes and
                                ;the A/D reading needs only 1 byte,
                                ;we need to write zeros into bytes
                                ;that we will not use.

        CLR     EXPONENT        ;clear the exponent of FPACC1
        CLR     MAN1            ;clear the first byte of the mantissa
        CLR     MAN2            ;clear the second byte of the mantissa
        CLR     SIGN            ;clear the sign

        STAA    MAN3            ;store the A/D conversion value
                                ;into the third-byte of the mantissa

                                ;convert unsigned integer to floating-point
        JSR     UINT2FLT        ;convert A/D value to floating-point
                                ;floating-point number is in FPACC1
        
        JSR     TFR1TO2         ;Transfer to FPACC2


                                ;now multiply FPACC1 * 1.937

        LDX     #CONST1         ;LOAD IX with the address for 1.937
        JSR     ASCFLT          ;convert ASCII 1.937 to floating-point
                                ;FPACC1 now has a floating-point number
                                ;for 1.937
        
        JSR     FLTMUL          ;1.937 * X
                                ;FPACC1 = FPACC1 * FPACC2

                                ;now convert float point to ASCII STRING
        LDX     #TBUFF          ;set IX to the beginning address
                                ;of string TBUFF.

        JSR     FLTASC          ;convert FLOATING_POINT to ASCII.
                                ;TBUFF now contains the temperature 
                                ;in Centigrate.

        JSR     LCDCLS          ;clear the LCD DISPLAY
        LDX     #TBUFF
        JSR     LCDTEXT         ;print out the temperature 

        JSR     DELAY           
        JSR     DELAY           
        JMP     MAIN            ;Repeat

;********************************************************
DELAY:
        PSHX
        LDX     #$FFFF
LOOP1   DEX
        BNE     LOOP1
        PULX
        RTS

        END




